{ Unit: BcDownloadProgress
  ===========================================================================

  The contents of this file are subject to the Bluecave Public License V 1.1
  (the "License"). You may not copy or use this file, in either source code
  or executable form, except in compliance with the License. You may obtain
  a copy of the License at http://www.bluecave.net/licenses/.

  Software distributed under the License is distributed on an "AS IS" basis,
  WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
  for the specific language governing rights and limitations under the
  License.

  Copyright (C) 2001 Bluecave Software. All Rights Reserved.
  http://www.bluecave.net/

  Copyright (C) 2001 Jouni Airaksinen. All Rights Reserved.
  http://Mintus.Codefield.com/ -- Mintus@Codefield.com

  ===========================================================================

  Unit description:

    Download progress form.

  History:

    2001-11-30: Initial version

  =========================================================================== }

{$I DFS.inc}
{$I BcDirectives.inc}

unit BcDownloadProgress;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, ComCtrls, IdAntiFreezeBase, IdAntiFreeze, IdBaseComponent,
  IdComponent, IdTCPConnection, IdTCPClient, IdHTTP;

type
  TBcDownloadProgressForm = class(TForm)
    BtnCancel: TButton;
    PBar: TProgressBar;
    LblStatus: TLabel;
    LblTransferStatus: TLabel;
    LblTransfer: TLabel;
    procedure BtnCancelClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
  private
    FHTTP: TIdHTTP;
    function GetStatusText: string;
    procedure SetStatusText(const Value: string);
    function GetTransferMax: Integer;
    function GetTransferPos: Integer;
    procedure SetTransferMax(const Value: Integer);
    procedure SetTransferPos(const Value: Integer);
    { Private declarations }
    procedure UpdateTransferStatus;
  public
    { Public declarations }
    property HTTP: TIdHTTP read FHTTP write FHTTP;
    property StatusText: string read GetStatusText write SetStatusText;
    property TransferMax: Integer read GetTransferMax write SetTransferMax;
    property TransferPos: Integer read GetTransferPos write SetTransferPos;
  end;

implementation

uses BcIndyHTTPFile;

{$R *.DFM}

procedure TBcDownloadProgressForm.BtnCancelClick(Sender: TObject);
begin
  if Assigned(HTTP) then
  begin
    HTTP.DisconnectSocket;
  end;
  Screen.Cursor := crDefault;
end;

procedure TBcDownloadProgressForm.FormCreate(Sender: TObject);
begin
  PBar.Position := 0;
end;

function TBcDownloadProgressForm.GetStatusText: string;
begin
  Result := LblStatus.Caption;
end;

function TBcDownloadProgressForm.GetTransferMax: Integer;
begin
  Result := PBar.Max;
end;

function TBcDownloadProgressForm.GetTransferPos: Integer;
begin
  Result := PBar.Position;
end;

procedure TBcDownloadProgressForm.SetStatusText(const Value: string);
begin
  LblStatus.Caption := Value;
end;

procedure TBcDownloadProgressForm.SetTransferMax(const Value: Integer);
begin
  PBar.Max := Value;
  UpdateTransferStatus;
//  Application.ProcessMessages;
end;

procedure TBcDownloadProgressForm.SetTransferPos(const Value: Integer);
begin
  PBar.Position := Value;
  UpdateTransferStatus;
//  Application.ProcessMessages;
end;

procedure TBcDownloadProgressForm.UpdateTransferStatus;
begin
  LblTransferStatus.Caption := Format('%d / %d', [PBar.Position, PBar.Max]);
end;

end.
